| inflation | R Documentation |
inflation represents data on variables that measures inflation in Bangladesh. Both point to point and 12 month average measures are included. Some of the measures are with base 1995-96 and the recent ones are with base 2005-06.
inflation
A data frame with four variables: date, inf_p2p_05,
inf_p2p_95, inf_12m_05, inf_12m_95. date starts from Fiscal year 2010, that is July 1, 2010 and ends on July 01, 2020. inf_p2p_05 and inf_p2p_95 represents point to point inflation with 2005 and 1995 base respectively. inf_12m_05 and inf_12m_95 represents tweleve month average inflation, again respectively for two base period mentioned above.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.